// -*- C++ -*-
/*!
 * @file LedCtrl.cpp
 * @brief RTComponent header
 * @date $Date$
 * @author Noriaki Ando <n-ando@aist.go.jp>
 *         Harumi Miyamoto
 *
 * Copyright (C) 2008
 *     Task-intelligence Research Group,
 *     Intelligent Systems Research Institute,
 *     National Institute of
 *         Advanced Industrial Science and Technology (AIST), Japan
 *     All rights reserved.
 *
 * $Id$
 *
 */

#include "LedCtrl.h"

namespace Armadillo
{

  LedCtrl::LedCtrl()
    : m_fd(-1)
  {
  }

  LedCtrl::~LedCtrl()
  {
  }

  bool LedCtrl::open(const char* devname)
  {
    m_fd = ::open(devname, O_RDWR);
    if (m_fd == -1)
      {
        perror("ledctrl: device open");
        return false;
      }
    return true;
  }
  
  bool LedCtrl::close()
  {
    int ret;
    ret = ::close(m_fd);
    return ret == -1 ? false : true;
  }

  void LedCtrl::red_on()
  {
    if (m_fd == -1) return;
    ioctl(m_fd, LED_RED_ON);
  }

  void LedCtrl::red_off()
  {
    if (m_fd == -1) return;
    ioctl(m_fd, LED_RED_OFF);
  }

  void LedCtrl::red_blink_on()
  {
    if (m_fd == -1) return;
    ioctl(m_fd, LED_RED_BLINKON);
  }

  void LedCtrl::red_blink_off()
  {
    if (m_fd == -1) return;
    ioctl(m_fd, LED_RED_BLINKOFF);
  }

  void LedCtrl::green_on()
  {
    if (m_fd == -1) return;
    ioctl(m_fd, LED_GREEN_ON);
  }

  void LedCtrl::green_off()
  {
    if (m_fd == -1) return;
    ioctl(m_fd, LED_GREEN_OFF);
  }

  void LedCtrl::green_blink_on()
  {
    if (m_fd == -1) return;
    ioctl(m_fd, LED_GREEN_BLINKON);
  }
  void LedCtrl::green_blink_off()
  {
    if (m_fd == -1) return;
    ioctl(m_fd, LED_GREEN_BLINKOFF);
  }

  bool LedCtrl::get_red_status()
  {
    char buf[16];
    ioctl(m_fd, LED_RED_STATUS, buf);
    return (buf[0] & LED_RED) ? true : false;
  }

  bool LedCtrl::get_green_status()
  {
    char buf[16];
    ioctl(m_fd, LED_GREEN_STATUS, buf);
    return buf[0] & LED_GREEN ? true : false;
  }

};

