// -*- C++ -*-
/*!
 * @file LedCtrl.h
 * @brief RTComponent header
 * @date $Date$
 * @author Noriaki Ando <n-ando@aist.go.jp>
 *         Harumi Miyamoto
 *
 * Copyright (C) 2008
 *     Task-intelligence Research Group,
 *     Intelligent Systems Research Institute,
 *     National Institute of
 *         Advanced Industrial Science and Technology (AIST), Japan
 *     All rights reserved.
 *
 * $Id$
 *
 */

#ifndef Armadillo_LedCtrl_h
#define Armadillo_LedCtrl_h

#include <stdio.h>
#include <unistd.h>
#include <fcntl.h>
#include <sys/types.h>
#include <sys/ioctl.h>

//read/write parameter
#define LED_RED               0x00000001
#define LED_GREEN             0x00000002

//ioctl command
#define LED_RED_ON            0x00000001
#define LED_RED_OFF           0x00000002
#define LED_RED_STATUS        0x00000004
#define LED_RED_BLINK         0x00000008
#define LED_RED_BLINKON       (LED_RED_BLINK | LED_RED_ON)
#define LED_RED_BLINKOFF      (LED_RED_BLINK | LED_RED_OFF)
#define LED_RED_BLINKSTATUS   (LED_RED_BLINK | LED_RED_STATUS)
#define LED_GREEN_ON          0x00000010
#define LED_GREEN_OFF         0x00000020
#define LED_GREEN_STATUS      0x00000040
#define LED_GREEN_BLINK       0x00000080
#define LED_GREEN_BLINKON     (LED_GREEN_BLINK | LED_GREEN_ON)
#define LED_GREEN_BLINKOFF    (LED_GREEN_BLINK | LED_GREEN_OFF)
#define LED_GREEN_BLINKSTATUS (LED_GREEN_BLINK | LED_GREEN_STATUS)


namespace Armadillo
{
  /*!
   * @if jp
   * @class Armadillo LED control class
   * @brief Armadillo
   *
   * @else
   *
   * @endif
   */
  class LedCtrl
  {
  public:
    /*!
     * @if jp
     * @brief Armadillo
     *
     * @else
     *
     * @endif
     */
    LedCtrl();
    
    /*!
     * @if jp
     * @brief Armadillo
     *
     * @else
     *
     * @endif
     */
    virtual ~LedCtrl();
    
    /*!
     * @if jp
     * @brief Armadillo
     *
     * @else
     *
     * @endif
     */
    bool open(const char* devname = "/dev/led");
    
    /*!
     * @if jp
     * @brief Armadillo
     *
     * @else
     *
     * @endif
     */
    bool close();

    /*!
     * @if jp
     * @brief Armadillo
     *
     * @else
     *
     * @endif
     */
    void red_on();

    /*!
     * @if jp
     * @brief Armadillo
     *
     * @else
     *
     * @endif
     */
    void red_off();

    /*!
     * @if jp
     * @brief Armadillo
     *
     * @else
     *
     * @endif
     */
    void red_blink_on();

    /*!
     * @if jp
     * @brief Armadillo
     *
     * @else
     *
     * @endif
     */
    void red_blink_off();

    /*!
     * @if jp
     * @brief Armadillo
     *
     * @else
     *
     * @endif
     */
    void green_on();

    /*!
     * @if jp
     * @brief Armadillo
     *
     * @else
     *
     * @endif
     */
    void green_off();

    /*!
     * @if jp
     * @brief Armadillo
     *
     * @else
     *
     * @endif
     */
    void green_blink_on();

    /*!
     * @if jp
     * @brief Armadillo
     *
     * @else
     *
     * @endif
     */
    void green_blink_off();
    
    /*!
     * @if jp
     * @brief LEDXe[^X
     *
     * @return true: LED_, false: LED_̓foCXG[
     *
     * @else
     *
     * @endif
     */
    bool get_red_status();

    /*!
     * @if jp
     * @class Armadillo LED control class
     * @brief Armadillo
     *
     * @else
     *
     * @endif
     */
    bool get_green_status();
    
  private:
    int m_fd;
  };
};

#endif // Armadillo_LedCtrl_h
